==> haskell-gitrev-1.3.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gitrev
version: 1.3.1
id: gitrev-1.3.1-GWZebipuES31VlD8DlE6Dn
key: gitrev-1.3.1-GWZebipuES31VlD8DlE6Dn
license: BSD-3-Clause
maintainer: acfoltzer@galois.com
author: Adam C. Foltzer
homepage: https://github.com/acfoltzer/gitrev
synopsis: Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.
category: Development
abi: 71783bb73804f30956ad9c60648373cc
exposed: True
exposed-modules:
    Development.GitRev
import-dirs: /usr/lib/ghc-8.4.3/site-local/gitrev-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/gitrev-1.3.1
hs-libraries: HSgitrev-1.3.1-GWZebipuES31VlD8DlE6Dn
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    directory-1.3.1.5 filepath-1.4.2 template-haskell-2.13.0.0
    process-1.6.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
haddock-interfaces: /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html: /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gitrev-1.3.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gitrev
version: 1.3.1
id: gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
key: gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
license: BSD-3-Clause
maintainer: acfoltzer@galois.com
author: Adam C. Foltzer
homepage: https://github.com/acfoltzer/gitrev
synopsis: Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.
category: Development
abi: dfadfabf13d3d9a6719171042287531b
exposed: True
exposed-modules:
    Development.GitRev
import-dirs: /usr/lib/ghc-8.4.3/site-local/gitrev-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/gitrev-1.3.1
hs-libraries: HSgitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    directory-1.3.1.5 filepath-1.4.2 template-haskell-2.13.0.0
    process-1.6.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
haddock-interfaces: /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html: /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
